Struct AnyNumeric

pub struct AnyNumeric { /* private fields */ }
A plain Postgres SQL NUMERIC with default precision and scale values. This is a sufficient type to represent any Rust primitive value from i128::MIN to u128::MAX and anything in between.

Generally, this is the type you’ll want to use as function arguments.

Implementations

Source

impl AnyNumeric

pub fn sign(&self) -> Sign

Returns the sign of this AnyNumeric

pub fn is_nan(&self) -> bool

Is this AnyNumeric not-a-number?

pub fn abs(&self) -> AnyNumeric

The absolute value of this AnyNumeric

pub fn log(&self, base: AnyNumeric) -> AnyNumeric

Compute the logarithm of this AnyNumeric in the given base

pub fn exp(x: &AnyNumeric) -> AnyNumeric

Raise e to the power of x

pub fn sqrt(&self) -> AnyNumeric

Compute the square root of this AnyNumeric

pub fn ceil(&self) -> AnyNumeric

Return the smallest integer greater than or equal to this AnyNumeric

pub fn floor(&self) -> AnyNumeric

Return the largest integer equal to or less than this AnyNumeric

pub fn gcd(&self, n: &AnyNumeric) -> AnyNumeric

Calculate the greatest common divisor of this an another AnyNumeric

pub fn normalize(&self) -> &str

Output function for numeric data type, suppressing insignificant trailing zeroes and then any trailing decimal point. The intent of this is to produce strings that are equal if and only if the input numeric values compare equal.

pub fn rescale<const P: u32, const S: u32>(self) -> Result<Numeric<P, S>, Error>

Consume this AnyNumeric and apply a Precision and Scale.

Returns an Error if this AnyNumeric doesn’t fit within the new constraints.

Examples
use pgrx::{AnyNumeric, Numeric};
let start = AnyNumeric::try_from(42.42).unwrap();
let rescaled:f32 = start.rescale::<3, 1>().unwrap().try_into().unwrap();
assert_eq!(rescaled, 42.4);