Struct TimeWithTimeZone

pub struct TimeWithTimeZone(/* private fields */);
A safe wrapper around Postgres TIME WITH TIME ZONE type, backed by a pg_sys::TimeTzADT integer value.

Implementations

Source

impl TimeWithTimeZone

pub fn new( hour: u8, minute: u8, second: f64, ) -> Result<TimeWithTimeZone, DateTimeConversionError>

Construct a new TimeWithTimeZone from its constituent parts.

Notes

This function uses Postgres’ “current time zone”

Errors

Returns a DateTimeConversionError if any part is outside the bounds for that part

pub fn new_unchecked(hour: u8, minute: u8, second: f64) -> TimeWithTimeZone

Construct a new TimeWithTimeZone from its constituent parts.

Elides the overhead of trapping errors for out-of-bounds parts

Notes

This function uses Postgres’ “current time zone”

Panics

This function panics if any part is out-of-bounds

pub fn with_timezone<Tz>( hour: u8, minute: u8, second: f64, timezone: Tz, ) -> Result<TimeWithTimeZone, DateTimeConversionError>

Construct a new TimeWithTimeZone from its constituent parts at a specific time zone

Errors

Returns a DateTimeConversionError if any part is outside the bounds for that part

pub fn with_timezone_offset( hour: u8, minute: u8, second: f64, timezone_offset: Interval, ) -> Result<TimeWithTimeZone, DateTimeConversionError>

Construct a new TimeWithTimeZone from its constituent parts at a specific time zone Interval

Errors

Returns a DateTimeConversionError if any part is outside the bounds for that part

pub fn hour(&self) -> u8

Extract the hour

pub fn minute(&self) -> u8

Extract the minute

pub fn second(&self) -> f64

Extract the second

pub fn microseconds(&self) -> u32

Return the microseconds part. This is not the time counted in microseconds, but the fractional seconds

pub fn timezone_offset(&self) -> i32

Extract the timezone, measured in seconds past GMT

pub fn timezone_hour(&self) -> i32

Extract the timezone_hour, measured in hours past GMT

pub fn timezone_minute(&self) -> i32

Extract the timezone_minute, measured in hours past GMT

pub fn to_hms_micro(&self) -> (u8, u8, u8, u32)

Return the hour, minute, second, and microseconds as a Rust tuple

pub fn to_utc(&self) -> Time

Shift this TimeWithTimeZone to UTC

pub fn at_timezone<Tz>( &self, timezone: Tz, ) -> Result<TimeWithTimeZone, DateTimeConversionError>

Shift the TimeWithTimeZone to the specified time zone

Errors

Returns a DateTimeConversionError if the specified time zone is invalid or if for some other reason the underlying time cannot be represented in the specified time zone

pub fn into_inner(self) -> TimeTzADT

Return the backing pg_sys::TimeTzADT value.