pub struct Timestamp(/* private fields */);Expand description
A safe wrapper around Postgres TIMESTAMP WITHOUT TIME ZONE type, backed by a pg_sys::Timestamp integer value.
Implementations
Sourceimpl Timestamp
impl Timestamp
Sourcepub fn new(
year: i32,
month: u8,
day: u8,
hour: u8,
minute: u8,
second: f64,
) -> Result<Timestamp, DateTimeConversionError>
pub fn new( year: i32, month: u8, day: u8, hour: u8, minute: u8, second: f64, ) -> Result<Timestamp, DateTimeConversionError>
Construct a new Timestamp from its constituent parts.
Errors
Returns a DateTimeConversionError if any part is outside the bounds for that part
Sourcepub fn new_unchecked(
year: isize,
month: u8,
day: u8,
hour: u8,
minute: u8,
second: f64,
) -> Timestamp
pub fn new_unchecked( year: isize, month: u8, day: u8, hour: u8, minute: u8, second: f64, ) -> Timestamp
Sourcepub fn positive_infinity() -> Timestamp
pub fn positive_infinity() -> Timestamp
Construct a new Timestamp representing positive infinity
Sourcepub fn negative_infinity() -> Timestamp
pub fn negative_infinity() -> Timestamp
Construct a new Timestamp representing negative infinity
Sourcepub fn is_infinity(&self) -> bool
pub fn is_infinity(&self) -> bool
Does this Timestamp represent positive infinity?
Sourcepub fn is_neg_infinity(&self) -> bool
pub fn is_neg_infinity(&self) -> bool
Does this Timestamp represent negative infinity?
Sourcepub fn microseconds(&self) -> u32
pub fn microseconds(&self) -> u32
Return the microseconds part. This is not the time counted in microseconds, but the
fractional seconds
Sourcepub fn to_hms_micro(&self) -> (u8, u8, u8, u32)
pub fn to_hms_micro(&self) -> (u8, u8, u8, u32)
Return the hour, minute, second, and microseconds as a Rust tuple
pub fn is_finite(&self) -> bool
Sourcepub fn truncate(self, units: DateTimeParts) -> Timestamp
pub fn truncate(self, units: DateTimeParts) -> Timestamp
Truncate Timestamp to specified units
Sourcepub fn age(&self, other: &Timestamp) -> Interval
pub fn age(&self, other: &Timestamp) -> Interval
Subtract other from self, producing a “symbolic” result that uses years and months, rather than just days
Sourcepub fn into_inner(self) -> i64
pub fn into_inner(self) -> i64
Return the backing pg_sys::Timestamp value.