Struct TimestampWithTimeZone

pub struct TimestampWithTimeZone(/* private fields */);
A safe wrapper around Postgres TIMESTAMP WITH TIME ZONE type, backed by a pg_sys::Timestamp integer value.

Implementations

Source

impl TimestampWithTimeZone

pub fn new( year: i32, month: u8, day: u8, hour: u8, minute: u8, second: f64, ) -> Result<TimestampWithTimeZone, DateTimeConversionError>

Construct a new TimestampWithTimeZone from its constituent parts.

Notes

This function uses Postgres’ “current time zone”

Errors

Returns a DateTimeConversionError if any part is outside the bounds for that part

pub fn new_unchecked( year: isize, month: u8, day: u8, hour: u8, minute: u8, second: f64, ) -> TimestampWithTimeZone

Construct a new TimestampWithTimeZone from its constituent parts.

Elides the overhead of trapping errors for out-of-bounds parts

Notes

This function uses Postgres’ “current time zone”

Panics

This function panics if any part is out-of-bounds

pub fn with_timezone<Tz>( year: i32, month: u8, day: u8, hour: u8, minute: u8, second: f64, timezone: Tz, ) -> Result<TimestampWithTimeZone, DateTimeConversionError>

Construct a new TimestampWithTimeZone from its constituent parts at a specific time zone

Errors

Returns a DateTimeConversionError if any part is outside the bounds for that part

pub fn positive_infinity() -> TimestampWithTimeZone

Construct a new TimestampWithTimeZone representing positive infinity

pub fn negative_infinity() -> TimestampWithTimeZone

Construct a new TimestampWithTimeZone representing negative infinity

pub fn is_infinity(&self) -> bool

Does this TimestampWithTimeZone represent positive infinity?

pub fn is_neg_infinity(&self) -> bool

Does this TimestampWithTimeZone represent negative infinity?

pub fn month(&self) -> u8

Extract the month

pub fn day(&self) -> u8

Extract the day

pub fn year(&self) -> i32

Extract the year

pub fn hour(&self) -> u8

Extract the hour

pub fn minute(&self) -> u8

Extract the minute

pub fn second(&self) -> f64

Extract the second

pub fn microseconds(&self) -> u32

Return the microseconds part. This is not the time counted in microseconds, but the fractional seconds

pub fn to_hms_micro(&self) -> (u8, u8, u8, u32)

Return the hour, minute, second, and microseconds as a Rust tuple

pub fn to_utc(&self) -> Timestamp

Shift the Timestamp to the UTC time zone

pub fn at_timezone<Tz>( &self, timezone: Tz, ) -> Result<Timestamp, DateTimeConversionError>

Shift the TimestampWithTimeZone to the specified time zone

Errors

Returns a DateTimeConversionError if the specified time zone is invalid or if for some other reason the underlying time cannot be represented in the specified time zone

pub fn is_finite(&self) -> bool

pub fn truncate(self, units: DateTimeParts) -> TimestampWithTimeZone

Truncate TimestampWithTimeZone to specified units

pub fn truncate_with_time_zone<Tz>( self, units: DateTimeParts, zone: Tz, ) -> TimestampWithTimeZone
where Tz: AsRef<str>,

Truncate TimestampWithTimeZone to specified units in specified time zone

Not available under Postgres v11

pub fn age(&self, other: &TimestampWithTimeZone) -> Interval

Subtract other from self, producing a “symbolic” result that uses years and months, rather than just days

pub fn into_inner(self) -> i64

Return the backing pg_sys::TimestampTz value.