#[repr(C, packed(2))]pub struct ItemPointerData {
pub ip_blkid: BlockIdData,
pub ip_posid: u16,
}Fields
ip_blkid: BlockIdDataip_posid: u16Trait Implementations
Sourceimpl Clone for ItemPointerData
impl Clone for ItemPointerData
Sourcefn clone(&self) -> ItemPointerData
fn clone(&self) -> ItemPointerData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ItemPointerData
impl Debug for ItemPointerData
Sourceimpl Default for ItemPointerData
impl Default for ItemPointerData
Sourcefn default() -> ItemPointerData
fn default() -> ItemPointerData
Returns the “default value” for a type. Read more
Sourceimpl FromDatum for ItemPointerData
impl FromDatum for ItemPointerData
Sourceunsafe fn from_polymorphic_datum(
datum: Datum,
is_null: bool,
_typoid: Oid,
) -> Option<ItemPointerData>
unsafe fn from_polymorphic_datum( datum: Datum, is_null: bool, _typoid: Oid, ) -> Option<ItemPointerData>
Like
from_datum for instantiating polymorphic types
which require preserving the dynamic type metadata. Read moreSourceconst GET_TYPOID: bool = false
const GET_TYPOID: bool = false
Should a type OID be fetched when calling
from_datum?Sourceunsafe fn from_datum(datum: Datum, is_null: bool) -> Option<Self>where
Self: Sized,
unsafe fn from_datum(datum: Datum, is_null: bool) -> Option<Self>where
Self: Sized,
Safety Read more
Sourceunsafe fn from_datum_in_memory_context(
memory_context: PgMemoryContexts,
datum: Datum,
is_null: bool,
typoid: Oid,
) -> Option<Self>where
Self: Sized,
unsafe fn from_datum_in_memory_context(
memory_context: PgMemoryContexts,
datum: Datum,
is_null: bool,
typoid: Oid,
) -> Option<Self>where
Self: Sized,
Default implementation switched to the specified memory context and then simply calls
FromDatum::from_datum(...) from within that context. Read moreSourceunsafe fn try_from_datum(
datum: Datum,
is_null: bool,
type_oid: Oid,
) -> Result<Option<Self>, TryFromDatumError>
unsafe fn try_from_datum( datum: Datum, is_null: bool, type_oid: Oid, ) -> Result<Option<Self>, TryFromDatumError>
try_from_datum is a convenience wrapper around FromDatum::from_datum that returns a
a Result around an Option, as a Datum can be null. It’s intended to be used in
situations where the caller needs to know whether the type conversion succeeded or failed. Read moreSourceunsafe fn try_from_datum_in_memory_context(
memory_context: PgMemoryContexts,
datum: Datum,
is_null: bool,
type_oid: Oid,
) -> Result<Option<Self>, TryFromDatumError>
unsafe fn try_from_datum_in_memory_context( memory_context: PgMemoryContexts, datum: Datum, is_null: bool, type_oid: Oid, ) -> Result<Option<Self>, TryFromDatumError>
A version of
try_from_datum that switches to the given context to convert from DatumSourceimpl IntoDatum for ItemPointerData
impl IntoDatum for ItemPointerData
Sourceimpl SqlTranslatable for ItemPointerData
impl SqlTranslatable for ItemPointerData
fn argument_sql() -> Result<SqlMapping, ArgumentError>
fn return_sql() -> Result<Returns, ReturnsError>
fn type_name() -> &'static str
fn variadic() -> bool
fn optional() -> bool
fn entity() -> FunctionMetadataTypeEntity
impl Copy for ItemPointerData