pub struct AnyNumeric { /* private fields */ }Expand description
A plain Postgres SQL NUMERIC with default precision and scale values. This is a sufficient type
to represent any Rust primitive value from i128::MIN to u128::MAX and anything in between.
Generally, this is the type you’ll want to use as function arguments.
Implementations
Sourceimpl AnyNumeric
impl AnyNumeric
Sourcepub fn sign(&self) -> Sign
pub fn sign(&self) -> Sign
Returns the sign of this AnyNumeric
Sourcepub fn is_nan(&self) -> bool
pub fn is_nan(&self) -> bool
Is this AnyNumeric not-a-number?
Sourcepub fn abs(&self) -> AnyNumeric
pub fn abs(&self) -> AnyNumeric
The absolute value of this AnyNumeric
Sourcepub fn log(&self, base: AnyNumeric) -> AnyNumeric
pub fn log(&self, base: AnyNumeric) -> AnyNumeric
Compute the logarithm of this AnyNumeric in the given base
Sourcepub fn exp(x: &AnyNumeric) -> AnyNumeric
pub fn exp(x: &AnyNumeric) -> AnyNumeric
Raise e to the power of x
Sourcepub fn sqrt(&self) -> AnyNumeric
pub fn sqrt(&self) -> AnyNumeric
Compute the square root of this AnyNumeric
Sourcepub fn ceil(&self) -> AnyNumeric
pub fn ceil(&self) -> AnyNumeric
Return the smallest integer greater than or equal to this AnyNumeric
Sourcepub fn floor(&self) -> AnyNumeric
pub fn floor(&self) -> AnyNumeric
Return the largest integer equal to or less than this AnyNumeric
Sourcepub fn gcd(&self, n: &AnyNumeric) -> AnyNumeric
pub fn gcd(&self, n: &AnyNumeric) -> AnyNumeric
Calculate the greatest common divisor of this an another AnyNumeric
Sourcepub fn normalize(&self) -> &str
pub fn normalize(&self) -> &str
Output function for numeric data type, suppressing insignificant trailing zeroes and then any trailing decimal point. The intent of this is to produce strings that are equal if and only if the input numeric values compare equal.
Sourcepub fn rescale<const P: u32, const S: u32>(self) -> Result<Numeric<P, S>, Error>
pub fn rescale<const P: u32, const S: u32>(self) -> Result<Numeric<P, S>, Error>
Consume this AnyNumeric and apply a Precision and Scale.
Returns an Error if this AnyNumeric doesn’t fit within the new constraints.
Examples
use pgrx::{AnyNumeric, Numeric};
let start = AnyNumeric::try_from(42.42).unwrap();
let rescaled:f32 = start.rescale::<3, 1>().unwrap().try_into().unwrap();
assert_eq!(rescaled, 42.4);Trait Implementations
Sourceimpl<const Q: u32, const T: u32> Add<Numeric<Q, T>> for AnyNumeric
Numeric on the left, AnyNumeric on the right. Results in a new AnyNumeric
impl<const Q: u32, const T: u32> Add<Numeric<Q, T>> for AnyNumeric
Numeric on the left, AnyNumeric on the right. Results in a new AnyNumeric
Sourceimpl Add<f32> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Add<f32> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Add<f64> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Add<f64> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Add<i128> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Add<i128> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Add<i16> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Add<i16> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Add<i32> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Add<i32> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Add<i64> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Add<i64> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Add<i8> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Add<i8> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Add<isize> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Add<isize> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Add<u128> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Add<u128> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Add<u16> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Add<u16> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Add<u32> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Add<u32> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Add<u64> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Add<u64> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Add<u8> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Add<u8> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Add<usize> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Add<usize> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Add for AnyNumeric
impl Add for AnyNumeric
Sourcetype Output = AnyNumeric
type Output = AnyNumeric
+ operator.Sourcefn add(self, rhs: AnyNumeric) -> <AnyNumeric as Add>::Output
fn add(self, rhs: AnyNumeric) -> <AnyNumeric as Add>::Output
+ operation. Read moreSourceimpl AddAssign<f32> for AnyNumeric
impl AddAssign<f32> for AnyNumeric
Sourcefn add_assign(&mut self, rhs: f32)
fn add_assign(&mut self, rhs: f32)
+= operation. Read moreSourceimpl AddAssign<f64> for AnyNumeric
impl AddAssign<f64> for AnyNumeric
Sourcefn add_assign(&mut self, rhs: f64)
fn add_assign(&mut self, rhs: f64)
+= operation. Read moreSourceimpl AddAssign<i128> for AnyNumeric
impl AddAssign<i128> for AnyNumeric
Sourcefn add_assign(&mut self, rhs: i128)
fn add_assign(&mut self, rhs: i128)
+= operation. Read moreSourceimpl AddAssign<i16> for AnyNumeric
impl AddAssign<i16> for AnyNumeric
Sourcefn add_assign(&mut self, rhs: i16)
fn add_assign(&mut self, rhs: i16)
+= operation. Read moreSourceimpl AddAssign<i32> for AnyNumeric
impl AddAssign<i32> for AnyNumeric
Sourcefn add_assign(&mut self, rhs: i32)
fn add_assign(&mut self, rhs: i32)
+= operation. Read moreSourceimpl AddAssign<i64> for AnyNumeric
impl AddAssign<i64> for AnyNumeric
Sourcefn add_assign(&mut self, rhs: i64)
fn add_assign(&mut self, rhs: i64)
+= operation. Read moreSourceimpl AddAssign<i8> for AnyNumeric
impl AddAssign<i8> for AnyNumeric
Sourcefn add_assign(&mut self, rhs: i8)
fn add_assign(&mut self, rhs: i8)
+= operation. Read moreSourceimpl AddAssign<isize> for AnyNumeric
impl AddAssign<isize> for AnyNumeric
Sourcefn add_assign(&mut self, rhs: isize)
fn add_assign(&mut self, rhs: isize)
+= operation. Read moreSourceimpl AddAssign<u128> for AnyNumeric
impl AddAssign<u128> for AnyNumeric
Sourcefn add_assign(&mut self, rhs: u128)
fn add_assign(&mut self, rhs: u128)
+= operation. Read moreSourceimpl AddAssign<u16> for AnyNumeric
impl AddAssign<u16> for AnyNumeric
Sourcefn add_assign(&mut self, rhs: u16)
fn add_assign(&mut self, rhs: u16)
+= operation. Read moreSourceimpl AddAssign<u32> for AnyNumeric
impl AddAssign<u32> for AnyNumeric
Sourcefn add_assign(&mut self, rhs: u32)
fn add_assign(&mut self, rhs: u32)
+= operation. Read moreSourceimpl AddAssign<u64> for AnyNumeric
impl AddAssign<u64> for AnyNumeric
Sourcefn add_assign(&mut self, rhs: u64)
fn add_assign(&mut self, rhs: u64)
+= operation. Read moreSourceimpl AddAssign<u8> for AnyNumeric
impl AddAssign<u8> for AnyNumeric
Sourcefn add_assign(&mut self, rhs: u8)
fn add_assign(&mut self, rhs: u8)
+= operation. Read moreSourceimpl AddAssign<usize> for AnyNumeric
impl AddAssign<usize> for AnyNumeric
Sourcefn add_assign(&mut self, rhs: usize)
fn add_assign(&mut self, rhs: usize)
+= operation. Read moreSourceimpl AddAssign for AnyNumeric
impl AddAssign for AnyNumeric
Sourcefn add_assign(&mut self, rhs: AnyNumeric)
fn add_assign(&mut self, rhs: AnyNumeric)
+= operation. Read moreSourceimpl Clone for AnyNumeric
impl Clone for AnyNumeric
Sourcefn clone(&self) -> AnyNumeric
fn clone(&self) -> AnyNumeric
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for AnyNumeric
impl Debug for AnyNumeric
Sourceimpl Default for AnyNumeric
impl Default for AnyNumeric
Sourcefn default() -> AnyNumeric
fn default() -> AnyNumeric
Sourceimpl<'de> Deserialize<'de> for AnyNumeric
impl<'de> Deserialize<'de> for AnyNumeric
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<AnyNumeric, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<AnyNumeric, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Sourceimpl Display for AnyNumeric
impl Display for AnyNumeric
Sourceimpl<const Q: u32, const T: u32> Div<Numeric<Q, T>> for AnyNumeric
Numeric on the left, AnyNumeric on the right. Results in a new AnyNumeric
impl<const Q: u32, const T: u32> Div<Numeric<Q, T>> for AnyNumeric
Numeric on the left, AnyNumeric on the right. Results in a new AnyNumeric
Sourceimpl Div<f32> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Div<f32> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Div<f64> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Div<f64> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Div<i128> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Div<i128> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Div<i16> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Div<i16> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Div<i32> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Div<i32> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Div<i64> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Div<i64> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Div<i8> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Div<i8> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Div<isize> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Div<isize> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Div<u128> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Div<u128> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Div<u16> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Div<u16> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Div<u32> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Div<u32> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Div<u64> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Div<u64> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Div<u8> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Div<u8> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Div<usize> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Div<usize> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Div for AnyNumeric
impl Div for AnyNumeric
Sourcetype Output = AnyNumeric
type Output = AnyNumeric
/ operator.Sourcefn div(self, rhs: AnyNumeric) -> <AnyNumeric as Div>::Output
fn div(self, rhs: AnyNumeric) -> <AnyNumeric as Div>::Output
/ operation. Read moreSourceimpl DivAssign<f32> for AnyNumeric
impl DivAssign<f32> for AnyNumeric
Sourcefn div_assign(&mut self, rhs: f32)
fn div_assign(&mut self, rhs: f32)
/= operation. Read moreSourceimpl DivAssign<f64> for AnyNumeric
impl DivAssign<f64> for AnyNumeric
Sourcefn div_assign(&mut self, rhs: f64)
fn div_assign(&mut self, rhs: f64)
/= operation. Read moreSourceimpl DivAssign<i128> for AnyNumeric
impl DivAssign<i128> for AnyNumeric
Sourcefn div_assign(&mut self, rhs: i128)
fn div_assign(&mut self, rhs: i128)
/= operation. Read moreSourceimpl DivAssign<i16> for AnyNumeric
impl DivAssign<i16> for AnyNumeric
Sourcefn div_assign(&mut self, rhs: i16)
fn div_assign(&mut self, rhs: i16)
/= operation. Read moreSourceimpl DivAssign<i32> for AnyNumeric
impl DivAssign<i32> for AnyNumeric
Sourcefn div_assign(&mut self, rhs: i32)
fn div_assign(&mut self, rhs: i32)
/= operation. Read moreSourceimpl DivAssign<i64> for AnyNumeric
impl DivAssign<i64> for AnyNumeric
Sourcefn div_assign(&mut self, rhs: i64)
fn div_assign(&mut self, rhs: i64)
/= operation. Read moreSourceimpl DivAssign<i8> for AnyNumeric
impl DivAssign<i8> for AnyNumeric
Sourcefn div_assign(&mut self, rhs: i8)
fn div_assign(&mut self, rhs: i8)
/= operation. Read moreSourceimpl DivAssign<isize> for AnyNumeric
impl DivAssign<isize> for AnyNumeric
Sourcefn div_assign(&mut self, rhs: isize)
fn div_assign(&mut self, rhs: isize)
/= operation. Read moreSourceimpl DivAssign<u128> for AnyNumeric
impl DivAssign<u128> for AnyNumeric
Sourcefn div_assign(&mut self, rhs: u128)
fn div_assign(&mut self, rhs: u128)
/= operation. Read moreSourceimpl DivAssign<u16> for AnyNumeric
impl DivAssign<u16> for AnyNumeric
Sourcefn div_assign(&mut self, rhs: u16)
fn div_assign(&mut self, rhs: u16)
/= operation. Read moreSourceimpl DivAssign<u32> for AnyNumeric
impl DivAssign<u32> for AnyNumeric
Sourcefn div_assign(&mut self, rhs: u32)
fn div_assign(&mut self, rhs: u32)
/= operation. Read moreSourceimpl DivAssign<u64> for AnyNumeric
impl DivAssign<u64> for AnyNumeric
Sourcefn div_assign(&mut self, rhs: u64)
fn div_assign(&mut self, rhs: u64)
/= operation. Read moreSourceimpl DivAssign<u8> for AnyNumeric
impl DivAssign<u8> for AnyNumeric
Sourcefn div_assign(&mut self, rhs: u8)
fn div_assign(&mut self, rhs: u8)
/= operation. Read moreSourceimpl DivAssign<usize> for AnyNumeric
impl DivAssign<usize> for AnyNumeric
Sourcefn div_assign(&mut self, rhs: usize)
fn div_assign(&mut self, rhs: usize)
/= operation. Read moreSourceimpl DivAssign for AnyNumeric
impl DivAssign for AnyNumeric
Sourcefn div_assign(&mut self, rhs: AnyNumeric)
fn div_assign(&mut self, rhs: AnyNumeric)
/= operation. Read moreSourceimpl<const P: u32, const S: u32> From<Numeric<P, S>> for AnyNumeric
impl<const P: u32, const S: u32> From<Numeric<P, S>> for AnyNumeric
Sourcefn from(n: Numeric<P, S>) -> AnyNumeric
fn from(n: Numeric<P, S>) -> AnyNumeric
Sourceimpl From<i128> for AnyNumeric
impl From<i128> for AnyNumeric
Sourcefn from(value: i128) -> AnyNumeric
fn from(value: i128) -> AnyNumeric
Sourceimpl From<i16> for AnyNumeric
impl From<i16> for AnyNumeric
Sourcefn from(value: i16) -> AnyNumeric
fn from(value: i16) -> AnyNumeric
Sourceimpl From<i32> for AnyNumeric
impl From<i32> for AnyNumeric
Sourcefn from(value: i32) -> AnyNumeric
fn from(value: i32) -> AnyNumeric
Sourceimpl From<i64> for AnyNumeric
impl From<i64> for AnyNumeric
Sourcefn from(value: i64) -> AnyNumeric
fn from(value: i64) -> AnyNumeric
Sourceimpl From<i8> for AnyNumeric
impl From<i8> for AnyNumeric
Sourcefn from(value: i8) -> AnyNumeric
fn from(value: i8) -> AnyNumeric
Sourceimpl From<isize> for AnyNumeric
impl From<isize> for AnyNumeric
Sourcefn from(value: isize) -> AnyNumeric
fn from(value: isize) -> AnyNumeric
Sourceimpl From<u128> for AnyNumeric
impl From<u128> for AnyNumeric
Sourcefn from(value: u128) -> AnyNumeric
fn from(value: u128) -> AnyNumeric
Sourceimpl From<u16> for AnyNumeric
impl From<u16> for AnyNumeric
Sourcefn from(value: u16) -> AnyNumeric
fn from(value: u16) -> AnyNumeric
Sourceimpl From<u32> for AnyNumeric
impl From<u32> for AnyNumeric
Sourcefn from(value: u32) -> AnyNumeric
fn from(value: u32) -> AnyNumeric
Sourceimpl From<u64> for AnyNumeric
impl From<u64> for AnyNumeric
Sourcefn from(value: u64) -> AnyNumeric
fn from(value: u64) -> AnyNumeric
Sourceimpl From<u8> for AnyNumeric
impl From<u8> for AnyNumeric
Sourcefn from(value: u8) -> AnyNumeric
fn from(value: u8) -> AnyNumeric
Sourceimpl From<usize> for AnyNumeric
impl From<usize> for AnyNumeric
Sourcefn from(value: usize) -> AnyNumeric
fn from(value: usize) -> AnyNumeric
Sourceimpl FromDatum for AnyNumeric
impl FromDatum for AnyNumeric
Sourceunsafe fn from_polymorphic_datum(
datum: Datum,
is_null: bool,
_typoid: Oid,
) -> Option<AnyNumeric>where
AnyNumeric: Sized,
unsafe fn from_polymorphic_datum(
datum: Datum,
is_null: bool,
_typoid: Oid,
) -> Option<AnyNumeric>where
AnyNumeric: Sized,
from_datum for instantiating polymorphic types
which require preserving the dynamic type metadata. Read moreSourceconst GET_TYPOID: bool = false
const GET_TYPOID: bool = false
from_datum?Sourceunsafe fn from_datum(datum: Datum, is_null: bool) -> Option<Self>where
Self: Sized,
unsafe fn from_datum(datum: Datum, is_null: bool) -> Option<Self>where
Self: Sized,
Sourceunsafe fn from_datum_in_memory_context(
memory_context: PgMemoryContexts,
datum: Datum,
is_null: bool,
typoid: Oid,
) -> Option<Self>where
Self: Sized,
unsafe fn from_datum_in_memory_context(
memory_context: PgMemoryContexts,
datum: Datum,
is_null: bool,
typoid: Oid,
) -> Option<Self>where
Self: Sized,
FromDatum::from_datum(...) from within that context. Read moreSourceunsafe fn try_from_datum(
datum: Datum,
is_null: bool,
type_oid: Oid,
) -> Result<Option<Self>, TryFromDatumError>
unsafe fn try_from_datum( datum: Datum, is_null: bool, type_oid: Oid, ) -> Result<Option<Self>, TryFromDatumError>
try_from_datum is a convenience wrapper around FromDatum::from_datum that returns a
a Result around an Option, as a Datum can be null. It’s intended to be used in
situations where the caller needs to know whether the type conversion succeeded or failed. Read moreSourceunsafe fn try_from_datum_in_memory_context(
memory_context: PgMemoryContexts,
datum: Datum,
is_null: bool,
type_oid: Oid,
) -> Result<Option<Self>, TryFromDatumError>
unsafe fn try_from_datum_in_memory_context( memory_context: PgMemoryContexts, datum: Datum, is_null: bool, type_oid: Oid, ) -> Result<Option<Self>, TryFromDatumError>
try_from_datum that switches to the given context to convert from DatumSourceimpl FromStr for AnyNumeric
impl FromStr for AnyNumeric
Sourceimpl Hash for AnyNumeric
impl Hash for AnyNumeric
Sourceimpl IntoDatum for AnyNumeric
impl IntoDatum for AnyNumeric
Sourceimpl<const Q: u32, const T: u32> Mul<Numeric<Q, T>> for AnyNumeric
Numeric on the left, AnyNumeric on the right. Results in a new AnyNumeric
impl<const Q: u32, const T: u32> Mul<Numeric<Q, T>> for AnyNumeric
Numeric on the left, AnyNumeric on the right. Results in a new AnyNumeric
Sourceimpl Mul<f32> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Mul<f32> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Mul<f64> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Mul<f64> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Mul<i128> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Mul<i128> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Mul<i16> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Mul<i16> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Mul<i32> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Mul<i32> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Mul<i64> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Mul<i64> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Mul<i8> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Mul<i8> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Mul<isize> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Mul<isize> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Mul<u128> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Mul<u128> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Mul<u16> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Mul<u16> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Mul<u32> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Mul<u32> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Mul<u64> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Mul<u64> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Mul<u8> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Mul<u8> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Mul<usize> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Mul<usize> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Mul for AnyNumeric
impl Mul for AnyNumeric
Sourcetype Output = AnyNumeric
type Output = AnyNumeric
* operator.Sourcefn mul(self, rhs: AnyNumeric) -> <AnyNumeric as Mul>::Output
fn mul(self, rhs: AnyNumeric) -> <AnyNumeric as Mul>::Output
* operation. Read moreSourceimpl MulAssign<f32> for AnyNumeric
impl MulAssign<f32> for AnyNumeric
Sourcefn mul_assign(&mut self, rhs: f32)
fn mul_assign(&mut self, rhs: f32)
*= operation. Read moreSourceimpl MulAssign<f64> for AnyNumeric
impl MulAssign<f64> for AnyNumeric
Sourcefn mul_assign(&mut self, rhs: f64)
fn mul_assign(&mut self, rhs: f64)
*= operation. Read moreSourceimpl MulAssign<i128> for AnyNumeric
impl MulAssign<i128> for AnyNumeric
Sourcefn mul_assign(&mut self, rhs: i128)
fn mul_assign(&mut self, rhs: i128)
*= operation. Read moreSourceimpl MulAssign<i16> for AnyNumeric
impl MulAssign<i16> for AnyNumeric
Sourcefn mul_assign(&mut self, rhs: i16)
fn mul_assign(&mut self, rhs: i16)
*= operation. Read moreSourceimpl MulAssign<i32> for AnyNumeric
impl MulAssign<i32> for AnyNumeric
Sourcefn mul_assign(&mut self, rhs: i32)
fn mul_assign(&mut self, rhs: i32)
*= operation. Read moreSourceimpl MulAssign<i64> for AnyNumeric
impl MulAssign<i64> for AnyNumeric
Sourcefn mul_assign(&mut self, rhs: i64)
fn mul_assign(&mut self, rhs: i64)
*= operation. Read moreSourceimpl MulAssign<i8> for AnyNumeric
impl MulAssign<i8> for AnyNumeric
Sourcefn mul_assign(&mut self, rhs: i8)
fn mul_assign(&mut self, rhs: i8)
*= operation. Read moreSourceimpl MulAssign<isize> for AnyNumeric
impl MulAssign<isize> for AnyNumeric
Sourcefn mul_assign(&mut self, rhs: isize)
fn mul_assign(&mut self, rhs: isize)
*= operation. Read moreSourceimpl MulAssign<u128> for AnyNumeric
impl MulAssign<u128> for AnyNumeric
Sourcefn mul_assign(&mut self, rhs: u128)
fn mul_assign(&mut self, rhs: u128)
*= operation. Read moreSourceimpl MulAssign<u16> for AnyNumeric
impl MulAssign<u16> for AnyNumeric
Sourcefn mul_assign(&mut self, rhs: u16)
fn mul_assign(&mut self, rhs: u16)
*= operation. Read moreSourceimpl MulAssign<u32> for AnyNumeric
impl MulAssign<u32> for AnyNumeric
Sourcefn mul_assign(&mut self, rhs: u32)
fn mul_assign(&mut self, rhs: u32)
*= operation. Read moreSourceimpl MulAssign<u64> for AnyNumeric
impl MulAssign<u64> for AnyNumeric
Sourcefn mul_assign(&mut self, rhs: u64)
fn mul_assign(&mut self, rhs: u64)
*= operation. Read moreSourceimpl MulAssign<u8> for AnyNumeric
impl MulAssign<u8> for AnyNumeric
Sourcefn mul_assign(&mut self, rhs: u8)
fn mul_assign(&mut self, rhs: u8)
*= operation. Read moreSourceimpl MulAssign<usize> for AnyNumeric
impl MulAssign<usize> for AnyNumeric
Sourcefn mul_assign(&mut self, rhs: usize)
fn mul_assign(&mut self, rhs: usize)
*= operation. Read moreSourceimpl MulAssign for AnyNumeric
impl MulAssign for AnyNumeric
Sourcefn mul_assign(&mut self, rhs: AnyNumeric)
fn mul_assign(&mut self, rhs: AnyNumeric)
*= operation. Read moreSourceimpl Neg for AnyNumeric
impl Neg for AnyNumeric
Sourceimpl Ord for AnyNumeric
impl Ord for AnyNumeric
Sourcefn cmp(&self, other: &AnyNumeric) -> Ordering
fn cmp(&self, other: &AnyNumeric) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl PartialEq for AnyNumeric
impl PartialEq for AnyNumeric
Sourcefn eq(&self, other: &AnyNumeric) -> bool
fn eq(&self, other: &AnyNumeric) -> bool
Postgres implementation detail: Unlike in Rust, Postgres considers NaN as equal
Sourcefn ne(&self, other: &AnyNumeric) -> bool
fn ne(&self, other: &AnyNumeric) -> bool
!=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.Sourceimpl PartialOrd for AnyNumeric
impl PartialOrd for AnyNumeric
Sourcefn partial_cmp(&self, other: &AnyNumeric) -> Option<Ordering>
fn partial_cmp(&self, other: &AnyNumeric) -> Option<Ordering>
Postgres implementation detail: Unlike in Rust, Postgres considers NaN as equal
Sourcefn lt(&self, other: &AnyNumeric) -> bool
fn lt(&self, other: &AnyNumeric) -> bool
Sourcefn le(&self, other: &AnyNumeric) -> bool
fn le(&self, other: &AnyNumeric) -> bool
Sourcefn gt(&self, other: &AnyNumeric) -> bool
fn gt(&self, other: &AnyNumeric) -> bool
Sourceimpl RangeSubType for AnyNumeric
for numeric/numrange
impl RangeSubType for AnyNumeric
for numeric/numrange
fn range_type_oid() -> Oid
Sourceimpl<const Q: u32, const T: u32> Rem<Numeric<Q, T>> for AnyNumeric
Numeric on the left, AnyNumeric on the right. Results in a new AnyNumeric
impl<const Q: u32, const T: u32> Rem<Numeric<Q, T>> for AnyNumeric
Numeric on the left, AnyNumeric on the right. Results in a new AnyNumeric
Sourceimpl Rem<f32> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Rem<f32> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Rem<f64> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Rem<f64> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Rem<i128> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Rem<i128> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Rem<i16> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Rem<i16> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Rem<i32> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Rem<i32> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Rem<i64> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Rem<i64> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Rem<i8> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Rem<i8> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Rem<isize> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Rem<isize> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Rem<u128> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Rem<u128> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Rem<u16> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Rem<u16> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Rem<u32> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Rem<u32> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Rem<u64> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Rem<u64> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Rem<u8> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Rem<u8> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Rem<usize> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Rem<usize> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Rem for AnyNumeric
impl Rem for AnyNumeric
Sourcetype Output = AnyNumeric
type Output = AnyNumeric
% operator.Sourcefn rem(self, rhs: AnyNumeric) -> <AnyNumeric as Rem>::Output
fn rem(self, rhs: AnyNumeric) -> <AnyNumeric as Rem>::Output
% operation. Read moreSourceimpl RemAssign<f32> for AnyNumeric
impl RemAssign<f32> for AnyNumeric
Sourcefn rem_assign(&mut self, rhs: f32)
fn rem_assign(&mut self, rhs: f32)
%= operation. Read moreSourceimpl RemAssign<f64> for AnyNumeric
impl RemAssign<f64> for AnyNumeric
Sourcefn rem_assign(&mut self, rhs: f64)
fn rem_assign(&mut self, rhs: f64)
%= operation. Read moreSourceimpl RemAssign<i128> for AnyNumeric
impl RemAssign<i128> for AnyNumeric
Sourcefn rem_assign(&mut self, rhs: i128)
fn rem_assign(&mut self, rhs: i128)
%= operation. Read moreSourceimpl RemAssign<i16> for AnyNumeric
impl RemAssign<i16> for AnyNumeric
Sourcefn rem_assign(&mut self, rhs: i16)
fn rem_assign(&mut self, rhs: i16)
%= operation. Read moreSourceimpl RemAssign<i32> for AnyNumeric
impl RemAssign<i32> for AnyNumeric
Sourcefn rem_assign(&mut self, rhs: i32)
fn rem_assign(&mut self, rhs: i32)
%= operation. Read moreSourceimpl RemAssign<i64> for AnyNumeric
impl RemAssign<i64> for AnyNumeric
Sourcefn rem_assign(&mut self, rhs: i64)
fn rem_assign(&mut self, rhs: i64)
%= operation. Read moreSourceimpl RemAssign<i8> for AnyNumeric
impl RemAssign<i8> for AnyNumeric
Sourcefn rem_assign(&mut self, rhs: i8)
fn rem_assign(&mut self, rhs: i8)
%= operation. Read moreSourceimpl RemAssign<isize> for AnyNumeric
impl RemAssign<isize> for AnyNumeric
Sourcefn rem_assign(&mut self, rhs: isize)
fn rem_assign(&mut self, rhs: isize)
%= operation. Read moreSourceimpl RemAssign<u128> for AnyNumeric
impl RemAssign<u128> for AnyNumeric
Sourcefn rem_assign(&mut self, rhs: u128)
fn rem_assign(&mut self, rhs: u128)
%= operation. Read moreSourceimpl RemAssign<u16> for AnyNumeric
impl RemAssign<u16> for AnyNumeric
Sourcefn rem_assign(&mut self, rhs: u16)
fn rem_assign(&mut self, rhs: u16)
%= operation. Read moreSourceimpl RemAssign<u32> for AnyNumeric
impl RemAssign<u32> for AnyNumeric
Sourcefn rem_assign(&mut self, rhs: u32)
fn rem_assign(&mut self, rhs: u32)
%= operation. Read moreSourceimpl RemAssign<u64> for AnyNumeric
impl RemAssign<u64> for AnyNumeric
Sourcefn rem_assign(&mut self, rhs: u64)
fn rem_assign(&mut self, rhs: u64)
%= operation. Read moreSourceimpl RemAssign<u8> for AnyNumeric
impl RemAssign<u8> for AnyNumeric
Sourcefn rem_assign(&mut self, rhs: u8)
fn rem_assign(&mut self, rhs: u8)
%= operation. Read moreSourceimpl RemAssign<usize> for AnyNumeric
impl RemAssign<usize> for AnyNumeric
Sourcefn rem_assign(&mut self, rhs: usize)
fn rem_assign(&mut self, rhs: usize)
%= operation. Read moreSourceimpl RemAssign for AnyNumeric
impl RemAssign for AnyNumeric
Sourcefn rem_assign(&mut self, rhs: AnyNumeric)
fn rem_assign(&mut self, rhs: AnyNumeric)
%= operation. Read moreSourceimpl Serialize for AnyNumeric
impl Serialize for AnyNumeric
Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Sourceimpl SqlTranslatable for AnyNumeric
impl SqlTranslatable for AnyNumeric
fn argument_sql() -> Result<SqlMapping, ArgumentError>
fn return_sql() -> Result<Returns, ReturnsError>
fn type_name() -> &'static str
fn variadic() -> bool
fn optional() -> bool
fn entity() -> FunctionMetadataTypeEntity
Sourceimpl<const Q: u32, const T: u32> Sub<Numeric<Q, T>> for AnyNumeric
Numeric on the left, AnyNumeric on the right. Results in a new AnyNumeric
impl<const Q: u32, const T: u32> Sub<Numeric<Q, T>> for AnyNumeric
Numeric on the left, AnyNumeric on the right. Results in a new AnyNumeric
Sourceimpl Sub<f32> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Sub<f32> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Sub<f64> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Sub<f64> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Sub<i128> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Sub<i128> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Sub<i16> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Sub<i16> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Sub<i32> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Sub<i32> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Sub<i64> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Sub<i64> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Sub<i8> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Sub<i8> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Sub<isize> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Sub<isize> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Sub<u128> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Sub<u128> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Sub<u16> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Sub<u16> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Sub<u32> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Sub<u32> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Sub<u64> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Sub<u64> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Sub<u8> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Sub<u8> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Sub<usize> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
impl Sub<usize> for AnyNumeric
AnyNumeric on the left, rust primitive on the right. Results in an AnyNumeric
Sourceimpl Sub for AnyNumeric
impl Sub for AnyNumeric
Sourcetype Output = AnyNumeric
type Output = AnyNumeric
- operator.Sourcefn sub(self, rhs: AnyNumeric) -> <AnyNumeric as Sub>::Output
fn sub(self, rhs: AnyNumeric) -> <AnyNumeric as Sub>::Output
- operation. Read moreSourceimpl SubAssign<f32> for AnyNumeric
impl SubAssign<f32> for AnyNumeric
Sourcefn sub_assign(&mut self, rhs: f32)
fn sub_assign(&mut self, rhs: f32)
-= operation. Read moreSourceimpl SubAssign<f64> for AnyNumeric
impl SubAssign<f64> for AnyNumeric
Sourcefn sub_assign(&mut self, rhs: f64)
fn sub_assign(&mut self, rhs: f64)
-= operation. Read moreSourceimpl SubAssign<i128> for AnyNumeric
impl SubAssign<i128> for AnyNumeric
Sourcefn sub_assign(&mut self, rhs: i128)
fn sub_assign(&mut self, rhs: i128)
-= operation. Read moreSourceimpl SubAssign<i16> for AnyNumeric
impl SubAssign<i16> for AnyNumeric
Sourcefn sub_assign(&mut self, rhs: i16)
fn sub_assign(&mut self, rhs: i16)
-= operation. Read moreSourceimpl SubAssign<i32> for AnyNumeric
impl SubAssign<i32> for AnyNumeric
Sourcefn sub_assign(&mut self, rhs: i32)
fn sub_assign(&mut self, rhs: i32)
-= operation. Read moreSourceimpl SubAssign<i64> for AnyNumeric
impl SubAssign<i64> for AnyNumeric
Sourcefn sub_assign(&mut self, rhs: i64)
fn sub_assign(&mut self, rhs: i64)
-= operation. Read moreSourceimpl SubAssign<i8> for AnyNumeric
impl SubAssign<i8> for AnyNumeric
Sourcefn sub_assign(&mut self, rhs: i8)
fn sub_assign(&mut self, rhs: i8)
-= operation. Read moreSourceimpl SubAssign<isize> for AnyNumeric
impl SubAssign<isize> for AnyNumeric
Sourcefn sub_assign(&mut self, rhs: isize)
fn sub_assign(&mut self, rhs: isize)
-= operation. Read moreSourceimpl SubAssign<u128> for AnyNumeric
impl SubAssign<u128> for AnyNumeric
Sourcefn sub_assign(&mut self, rhs: u128)
fn sub_assign(&mut self, rhs: u128)
-= operation. Read moreSourceimpl SubAssign<u16> for AnyNumeric
impl SubAssign<u16> for AnyNumeric
Sourcefn sub_assign(&mut self, rhs: u16)
fn sub_assign(&mut self, rhs: u16)
-= operation. Read moreSourceimpl SubAssign<u32> for AnyNumeric
impl SubAssign<u32> for AnyNumeric
Sourcefn sub_assign(&mut self, rhs: u32)
fn sub_assign(&mut self, rhs: u32)
-= operation. Read moreSourceimpl SubAssign<u64> for AnyNumeric
impl SubAssign<u64> for AnyNumeric
Sourcefn sub_assign(&mut self, rhs: u64)
fn sub_assign(&mut self, rhs: u64)
-= operation. Read moreSourceimpl SubAssign<u8> for AnyNumeric
impl SubAssign<u8> for AnyNumeric
Sourcefn sub_assign(&mut self, rhs: u8)
fn sub_assign(&mut self, rhs: u8)
-= operation. Read moreSourceimpl SubAssign<usize> for AnyNumeric
impl SubAssign<usize> for AnyNumeric
Sourcefn sub_assign(&mut self, rhs: usize)
fn sub_assign(&mut self, rhs: usize)
-= operation. Read moreSourceimpl SubAssign for AnyNumeric
impl SubAssign for AnyNumeric
Sourcefn sub_assign(&mut self, rhs: AnyNumeric)
fn sub_assign(&mut self, rhs: AnyNumeric)
-= operation. Read moreSourceimpl Sum for AnyNumeric
impl Sum for AnyNumeric
Sourcefn sum<I>(iter: I) -> AnyNumericwhere
I: Iterator<Item = AnyNumeric>,
fn sum<I>(iter: I) -> AnyNumericwhere
I: Iterator<Item = AnyNumeric>,
Self from the elements by “summing up”
the items.Sourceimpl TryFrom<&CStr> for AnyNumeric
impl TryFrom<&CStr> for AnyNumeric
Sourceimpl TryFrom<&str> for AnyNumeric
impl TryFrom<&str> for AnyNumeric
Sourceimpl TryFrom<f32> for AnyNumeric
impl TryFrom<f32> for AnyNumeric
Sourceimpl TryFrom<f64> for AnyNumeric
impl TryFrom<f64> for AnyNumeric
impl Eq for AnyNumeric
Postgres implementation detail: Unlike in Rust, Postgres considers NaN as equal