pub struct TimeWithTimeZone(/* private fields */);Expand description
A safe wrapper around Postgres TIME WITH TIME ZONE type, backed by a pg_sys::TimeTzADT integer value.
Implementations
Sourceimpl TimeWithTimeZone
impl TimeWithTimeZone
Sourcepub fn new(
hour: u8,
minute: u8,
second: f64,
) -> Result<TimeWithTimeZone, DateTimeConversionError>
pub fn new( hour: u8, minute: u8, second: f64, ) -> Result<TimeWithTimeZone, DateTimeConversionError>
Construct a new TimeWithTimeZone from its constituent parts.
Notes
This function uses Postgres’ “current time zone”
Errors
Returns a DateTimeConversionError if any part is outside the bounds for that part
Sourcepub fn new_unchecked(hour: u8, minute: u8, second: f64) -> TimeWithTimeZone
pub fn new_unchecked(hour: u8, minute: u8, second: f64) -> TimeWithTimeZone
Construct a new TimeWithTimeZone from its constituent parts.
Elides the overhead of trapping errors for out-of-bounds parts
Notes
This function uses Postgres’ “current time zone”
Panics
This function panics if any part is out-of-bounds
Sourcepub fn with_timezone<Tz>(
hour: u8,
minute: u8,
second: f64,
timezone: Tz,
) -> Result<TimeWithTimeZone, DateTimeConversionError>
pub fn with_timezone<Tz>( hour: u8, minute: u8, second: f64, timezone: Tz, ) -> Result<TimeWithTimeZone, DateTimeConversionError>
Construct a new TimeWithTimeZone from its constituent parts at a specific time zone
Errors
Returns a DateTimeConversionError if any part is outside the bounds for that part
Sourcepub fn with_timezone_offset(
hour: u8,
minute: u8,
second: f64,
timezone_offset: Interval,
) -> Result<TimeWithTimeZone, DateTimeConversionError>
pub fn with_timezone_offset( hour: u8, minute: u8, second: f64, timezone_offset: Interval, ) -> Result<TimeWithTimeZone, DateTimeConversionError>
Construct a new TimeWithTimeZone from its constituent parts at a specific time zone Interval
Errors
Returns a DateTimeConversionError if any part is outside the bounds for that part
Sourcepub fn microseconds(&self) -> u32
pub fn microseconds(&self) -> u32
Return the microseconds part. This is not the time counted in microseconds, but the
fractional seconds
Sourcepub fn timezone_offset(&self) -> i32
pub fn timezone_offset(&self) -> i32
Extract the timezone, measured in seconds past GMT
Sourcepub fn timezone_hour(&self) -> i32
pub fn timezone_hour(&self) -> i32
Extract the timezone_hour, measured in hours past GMT
Sourcepub fn timezone_minute(&self) -> i32
pub fn timezone_minute(&self) -> i32
Extract the timezone_minute, measured in hours past GMT
Sourcepub fn to_hms_micro(&self) -> (u8, u8, u8, u32)
pub fn to_hms_micro(&self) -> (u8, u8, u8, u32)
Return the hour, minute, second, and microseconds as a Rust tuple
Sourcepub fn to_utc(&self) -> Time
pub fn to_utc(&self) -> Time
Shift this TimeWithTimeZone to UTC
Sourcepub fn at_timezone<Tz>(
&self,
timezone: Tz,
) -> Result<TimeWithTimeZone, DateTimeConversionError>
pub fn at_timezone<Tz>( &self, timezone: Tz, ) -> Result<TimeWithTimeZone, DateTimeConversionError>
Shift the TimeWithTimeZone to the specified time zone
Errors
Returns a DateTimeConversionError if the specified time zone is invalid or if for some
other reason the underlying time cannot be represented in the specified time zone
Sourcepub fn into_inner(self) -> TimeTzADT
pub fn into_inner(self) -> TimeTzADT
Return the backing pg_sys::TimeTzADT value.